==> 0.0.63.tar.gz: lib/src/widgets/files/video_viewer_storage.dart <==
import 'package:chewie/chewie.dart';
import 'package:verttice_logic/verttice_logic.dart';
import "package:flutter/material.dart";
import 'package:verttice_ui/verttice_ui.dart';
import 'package:video_player/video_player.dart';

class VideoViewerStorage extends StatefulWidget {
  final String path;
  final double? height;

  const VideoViewerStorage({
    Key? key,
    required this.path,
    this.height,
  }) : super(key: key);
  @override
  State createState() => _VideoViewerStorageState();
}

class _VideoViewerStorageState extends State<VideoViewerStorage> {
  late String _path;
  late Future<String?> _fetchData;

  @override
  void initState() {
    super.initState();
    _path = widget.path;

    _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
  }

  @override
  void didUpdateWidget(covariant VideoViewerStorage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_path != widget.path) {
      _path = widget.path;
      _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<String?>(
        future: _fetchData,
        builder: (BuildContext context, AsyncSnapshot<String?> snapdata) {
          return SnapBuilder<String?>(
              height: widget.height,
              snapshot: snapdata,
              erroBuilder: (dynamic error) => Center(
                    child: CircleAvatar(
                      backgroundColor: Colors.red,
                      child: ThemedIcons.fileUnknow(
                        iconStyle: IconStyle(
                          color: Colors.white,
                          size: 35,
                        ),
                      ),
                    ),
                  ),
              loadingBuilder: () => const ThemedProgress(),
              successBuilder: (String? data) {
                return _body(context, data ?? '');
              });
        });
  }

  Widget _body(BuildContext context, String downloadURL) {
    return SizedBox(
      height: widget.height ?? MediaQuery.of(context).size.height / 2.5,
      child: InkWell(
        onTap: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => VideoViewerFullPage(url: downloadURL),
            ),
          );
        },
        child: Container(
          decoration: const BoxDecoration(
            color: Colors.lightBlue,
            borderRadius: BorderRadius.all(
              Radius.circular(5.0),
            ),
          ),
          child: Center(
              child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              ThemedIcons.video(
                iconStyle: IconStyle(
                  size: ScreenSizeUtils.isMobile(context: context) ? 35 : 60,
                  color: Colors.white,
                ),
              ),
              if (!ScreenSizeUtils.isMobile(context: context))
                Column(
                  children: const [
                    SizedBox(
                      height: 20,
                    ),
                    SelectableText(
                      "Click here to view the video",
                      style: TextStyle(
                        color: Colors.white,
                      ),
                    )
                  ],
                ),
              const Divider(
                indent: 4,
                endIndent: 4,
                color: Colors.white,
              ),
              const SelectableText(
                "Video",
                style: TextStyle(
                  color: Colors.white,
                ),
              )
            ],
          )),
        ),
      ),
    );
  }
}

class VideoViewerFullPage extends StatefulWidget {
  final String url;
  final double? height;
  final bool showAppBar;
  const VideoViewerFullPage({
    Key? key,
    required this.url,
    this.height,
    this.showAppBar = true,
  }) : super(key: key);

  @override
  _VideoViewerFullPageState createState() => _VideoViewerFullPageState();
}

class _VideoViewerFullPageState extends State<VideoViewerFullPage> {
  late VideoPlayerController _videoPlayerController;
  ChewieController? _chewieController;
  late String _url;

  @override
  void initState() {
    super.initState();
    _url = widget.url;
    _initVideoPlayer();
  }

  @override
  void dispose() {
    super.dispose();
    _videoPlayerController.dispose();
    _chewieController?.dispose();
  }

  @override
  void didUpdateWidget(covariant VideoViewerFullPage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_url != widget.url) {
      _url = widget.url;
      _initVideoPlayer();
    }
  }

  Future<void> _initVideoPlayer() async {
    _videoPlayerController = VideoPlayerController.network(_url);
    await _videoPlayerController.initialize();
    _chewieController = ChewieController(
      videoPlayerController: _videoPlayerController,
      looping: true,
    );
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.grey[850],
      appBar: !widget.showAppBar
          ? null
          : AppBar(
              actions: [
                DownloadButton(
                  url: widget.url,
                  fileType: VFileType.mp4,
                ),
                sizedBoxH16,
              ],
              backgroundColor: Colors.black,
            ),
      floatingActionButton: CircleAvatar(
        child: DownloadButton(
          url: widget.url,
          fileType: VFileType.mp4,
        ),
      ),
      body: SizedBox(
        height: widget.height,
        child: Builder(builder: (BuildContext context) {
          if (_chewieController == null) {
            return const ThemedProgress();
          }

          return Center(
            child: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10.0),
              ),
              child: SafeArea(
                child: Chewie(
                  controller: _chewieController!,
                ),
              ),
            ),
          );
        }),
      ),
    );
  }
}

==> 0.0.64.tar.gz: lib/src/widgets/files/video_viewer_storage.dart <==
import 'package:chewie/chewie.dart';
import 'package:verttice_logic/verttice_logic.dart';
import "package:flutter/material.dart";
import 'package:verttice_ui/verttice_ui.dart';
import 'package:video_player/video_player.dart';

class VideoViewerStorage extends StatefulWidget {
  final String path;
  final double? height;

  const VideoViewerStorage({
    Key? key,
    required this.path,
    this.height,
  }) : super(key: key);
  @override
  State createState() => _VideoViewerStorageState();
}

class _VideoViewerStorageState extends State<VideoViewerStorage> {
  late String _path;
  late Future<String?> _fetchData;

  @override
  void initState() {
    super.initState();
    _path = widget.path;

    _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
  }

  @override
  void didUpdateWidget(covariant VideoViewerStorage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_path != widget.path) {
      _path = widget.path;
      _fetchData = VertticeUIConfig.instance.getStorageDownloadURL(path: _path);
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<String?>(
        future: _fetchData,
        builder: (BuildContext context, AsyncSnapshot<String?> snapdata) {
          return SnapBuilder<String?>(
              height: widget.height,
              snapshot: snapdata,
              erroBuilder: (dynamic error) => Center(
                    child: CircleAvatar(
                      backgroundColor: Colors.red,
                      child: ThemedIcons.fileUnknow(
                        iconStyle: IconStyle(
                          color: Colors.white,
                          size: 35,
                        ),
                      ),
                    ),
                  ),
              loadingBuilder: () => const ThemedProgress(),
              successBuilder: (String? data) {
                return _body(context, data ?? '');
              });
        });
  }

  Widget _body(BuildContext context, String downloadURL) {
    return SizedBox(
      height: widget.height ?? MediaQuery.of(context).size.height / 2.5,
      child: InkWell(
        onTap: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => VideoViewerFullPage(url: downloadURL),
            ),
          );
        },
        child: Container(
          decoration: const BoxDecoration(
            color: Colors.lightBlue,
            borderRadius: BorderRadius.all(
              Radius.circular(5.0),
            ),
          ),
          child: Center(
              child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              ThemedIcons.video(
                iconStyle: IconStyle(
                  color: Colors.white,
                ),
              ),
              const SelectableText(
                "Video",
                style: TextStyle(
                  color: Colors.white,
                ),
              )
            ],
          )),
        ),
      ),
    );
  }
}

class VideoViewerFullPage extends StatefulWidget {
  final String url;
  final double? height;
  final bool showAppBar;
  const VideoViewerFullPage({
    Key? key,
    required this.url,
    this.height,
    this.showAppBar = true,
  }) : super(key: key);

  @override
  _VideoViewerFullPageState createState() => _VideoViewerFullPageState();
}

class _VideoViewerFullPageState extends State<VideoViewerFullPage> {
  late VideoPlayerController _videoPlayerController;
  ChewieController? _chewieController;
  late String _url;

  @override
  void initState() {
    super.initState();
    _url = widget.url;
    _initVideoPlayer();
  }

  @override
  void dispose() {
    super.dispose();
    _videoPlayerController.dispose();
    _chewieController?.dispose();
  }

  @override
  void didUpdateWidget(covariant VideoViewerFullPage oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_url != widget.url) {
      _url = widget.url;
      _initVideoPlayer();
    }
  }

  Future<void> _initVideoPlayer() async {
    _videoPlayerController = VideoPlayerController.network(_url);
    await _videoPlayerController.initialize();
    _chewieController = ChewieController(
      videoPlayerController: _videoPlayerController,
      looping: true,
    );
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.grey[850],
      appBar: !widget.showAppBar
          ? null
          : AppBar(
              actions: [
                DownloadButton(
                  url: widget.url,
                  fileType: VFileType.mp4,
                ),
                sizedBoxH16,
              ],
              backgroundColor: Colors.black,
            ),
      floatingActionButtonLocation: FloatingActionButtonLocation.endTop,
      floatingActionButton: widget.showAppBar
          ? null
          : CircleAvatar(
              backgroundColor: Colors.lightBlue,
              child: DownloadButton(
                url: widget.url,
                fileType: VFileType.mp4,
              ),
            ),
      body: SizedBox(
        height: widget.height,
        child: Builder(builder: (BuildContext context) {
          if (_chewieController == null) {
            return const ThemedProgress();
          }

          return Center(
            child: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10.0),
              ),
              child: SafeArea(
                child: Chewie(
                  controller: _chewieController!,
                ),
              ),
            ),
          );
        }),
      ),
    );
  }
}
